"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_languageserver_types_1 = require("vscode-languageserver-types");
exports.snippets = {
    testcase: {
        prefix: 'testcase',
        body: [
            '<?php',
            '',
            'use PHPUnit\\Framework\\TestCase;',
            '',
            'class ${TM_FILENAME_BASE} extends TestCase',
            '{',
            '    $0',
            '}',
        ],
        description: 'PHPUnit: test case declaration',
    },
    test: {
        prefix: 'test',
        body: ['public function test$1()', '{', '    $0', '}'],
        description: 'PHPUnit: test',
    },
    setup: {
        prefix: 'setup',
        body: ['protected function setUp()', '{', '    parent::setUp()', '    $0', '}'],
        description: 'PHPUnit: setup method declaration',
    },
    teardown: {
        prefix: 'teardown',
        body: ['protected function tearDown()', '{', '    parent::tearDown()', '    $0', '}'],
        description: 'PHPUnit: teardown method declaration',
    },
};
class SnippetManager {
    constructor() {
        this.items = [];
        for (const name in exports.snippets) {
            const snippet = exports.snippets[name];
            const body = snippet.body instanceof Array ? snippet.body.join('\n') : snippet.body;
            this.items.push({
                label: snippet.prefix,
                kind: vscode_languageserver_types_1.CompletionItemKind.Snippet,
                insertTextFormat: vscode_languageserver_types_1.InsertTextFormat.Snippet,
                detail: body,
                insertText: body,
            });
        }
    }
    onCompletion() {
        return this.items;
    }
    onCompletionResolve(item) {
        return item;
    }
}
exports.SnippetManager = SnippetManager;
//# sourceMappingURL=snippet-manager.js.map